htpio API documentation
Description: *** Hardware Test Platform (HTP) Remote I/O Classes and Modules. *** …

# Module `htpio`

Hardware Test Platform (HTP) Remote I/O Classes and Modules.

HTPIO is an executable package, which allows the user to test or use some of its library functionality from the command line.

Set value using telnet:

    htpio -p telnet set --host 192.168.199.31 --pin 14 --val 1

Get value using socket:

    htpio -p socket get --host 192.168.199.31 --pin 14

Lock/Unlock pin:

    htpio -p telnet lock --host 192.168.199.31 --pin 14
    htpio -p socket unlock --host 192.168.199.31 --pin 14

Source code

    """
    *** Hardware Test Platform (HTP) Remote I/O Classes and Modules. ***

    HTPIO is an executable package, which allows the user to test or use some of
    its library functionality from the command line.

    *Set value using telnet:*

    ```
    htpio -p telnet set --host 192.168.199.31 --pin 14 --val 1
    ```

    *Get value using socket:*
    ```
    htpio -p socket get --host 192.168.199.31 --pin 14
    ```

    *Lock/Unlock pin:*
    ```
    htpio -p telnet lock --host 192.168.199.31 --pin 14
    htpio -p socket unlock --host 192.168.199.31 --pin 14
    ```
    """

    name = "htpio"

## Sub-modules

`htpio.bridge`

  This module provides the connection between the client application and the remote i/o implementation …

`htpio.decorators`

  This module implement various decorators such as function calls and exception logging. Decorators are used to implement additional functionality to a …

`htpio.exceptions`

  This module implements all exception classes used by htpio.

`htpio.socketio`

  This is a socket i/o control module wrapping the python pigpio client. PIGPIO is a client/server library using sockets for remote control of the …

`htpio.telnetio`

  This is a telnet client i/o control module. Telnet is a client/server text-oriented communication protocol using a virtual terminal connection and …